=== modified file 'drizzled/base.h'
--- drizzled/base.h	2008-08-02 00:10:25 +0000
+++ drizzled/base.h	2008-08-05 18:43:30 +0000
@@ -15,8 +15,15 @@
 
 /* This file includes constants used with all databases */
 
-#ifndef _my_base_h
-#define _my_base_h
+/** 
+ * @TODO Name this file something better and split it out if necessary.  
+ * base.h isn't descriptive, especially compared to global.h 
+ *
+ * @TODO Convert HA_XXX defines into enums and/or bitmaps
+ */
+
+#ifndef DRIZZLE_SERVER_BASE_H
+#define DRIZZLE_SERVER_BASE_H
 
 #ifndef stdin				/* Included first in handler */
 #define CHSIZE_USED
@@ -555,4 +562,4 @@
 /* invalidator function reference for Query Cache */
 typedef void (* invalidator_by_filename)(const char * filename);
 
-#endif /* _my_base_h */
+#endif /* DRIZZLE_SERVER_BASE_H */

=== modified file 'drizzled/global.h'
--- drizzled/global.h	2008-08-05 02:31:51 +0000
+++ drizzled/global.h	2008-08-05 18:43:30 +0000
@@ -15,8 +15,8 @@
 
 /* This is the include file that should be included 'first' in every C file. */
 
-#ifndef _global_h
-#define _global_h
+#ifndef DRIZZLE_SERVER_GLOBAL_H
+#define DRIZZLE_SERVER_GLOBAL_H
 
 #define HAVE_REPLICATION
 #define HAVE_EXTERNAL_CLIENT
@@ -51,9 +51,6 @@
 #endif
 
 #include "config.h"
-#if defined(__cplusplus) && defined(inline)
-#undef inline				/* fix configure problem */
-#endif
 
 /* Make it easier to add conditionl code for windows */
 #define IF_WIN(A,B) (B)
@@ -999,4 +996,4 @@
 
 #include <libdrizzle/gettext.h>
 
-#endif /* my_global_h */
+#endif /* DRIZZLE_SERVER_GLOBAL_H */

=== modified file 'drizzled/mysql_priv.h'
--- drizzled/mysql_priv.h	2008-08-04 23:58:04 +0000
+++ drizzled/mysql_priv.h	2008-08-05 18:43:30 +0000
@@ -21,6 +21,10 @@
   mysqlbinlog too (definition of SELECT_DISTINCT and others).
   The consequence is that 90% of the file is wrapped in \#ifndef MYSQL_CLIENT,
   except the part which must be in the server and in the client.
+
+  @TODO Name this file better. "priv" could mean private, privileged, privileges.
+
+  @TODO Get rid of the MYSQL_CLIENT and MYSQL_SERVER conditionals
 */
 
 #ifndef DRIZZLE_SERVER_MYSQL_PRIV_H
@@ -28,35 +32,66 @@
 
 #ifndef MYSQL_CLIENT
 
-#include <drizzled/global.h>
-#include <drizzled/version.h>
-#include <mysys/my_sys.h>
+/* Cross-platform portability code and standard includes */
+#include <drizzled/global.h>                    
+/* Server versioning information and defines */
+#include <drizzled/version.h>                   
+/* Lots of system-wide struct definitions like IO_CACHE, DYNAMIC_STRING, prototypes for all my_* functions */
+#include <mysys/my_sys.h>                       
+/* Convenience functions for working with times */
 #include <libdrizzle/my_time.h>
+/* Custom C string functions */
 #include <mystrings/m_string.h>
+/* Custom HASH API */
 #include <mysys/hash.h>
+/* Standard signals API */
 #include <signal.h>
+/* Deadlock-free table-list lock API */
 #include <mysys/thr_lock.h>
+/* Custom error API */
 #include <drizzled/error.h>
+/* Defines for the storage engine handler -- i.e. HA_XXX defines */
 #include <drizzled/base.h>			                /* Needed by field.h */
+/* Custom queue API */
 #include <mysys/queues.h>
-#include <drizzled/sql_bitmap.h>                /* Custom bitmap API */
+/* Custom Bitmap API */
+#include <drizzled/sql_bitmap.h>
+/* Custom templatized, type-safe Dynamic_Array API */
 #include "sql_array.h"
+/* The <strong>INTERNAL</strong> plugin API - not the external, or public, server plugin API */
 #include "sql_plugin.h"
+/* The <strong>connection</strong> thread scheduler API */
 #include "scheduler.h"
+/* Network database operations (hostent, netent, servent, etc...*/
+#include <netdb.h>
+/* Communication API between a client and the server */
+#include <libdrizzle/drizzle_com.h>
 
 #ifdef HAVE_DTRACE
 #define _DTRACE_VERSION 1
 #endif
 #include "probes.h"
 
-#include <netdb.h>
-
 /**
   Query type constants.
 
   QT_ORDINARY -- ordinary SQL query.
   QT_IS -- SQL query to be shown in INFORMATION_SCHEMA (in utf8 and without
   character set introducers).
+
+  @TODO
+
+  Move this out of here once Stew's done with UDF breakout.  The following headers need it:
+
+    sql_lex.h --> included by sql_class.h
+    item.h
+    table.h
+    item_func.h
+    item_subselect.h
+    item_timefunc.h
+    item_sum.h
+    item_cmpfunc.h
+    item_strfunc.h
 */
 enum enum_query_type
 {
@@ -64,7 +99,30 @@
   QT_IS
 };
 
-/* TODO convert all these three maps to Bitmap classes */
+/** 
+ * @TODO convert all these three maps to Bitmap classes 
+ *
+ * @TODO Move these to a more appropriate header file (maps.h?).  The following files use them:
+ *
+ *    item_sum.h
+ *    item_compfunc.h
+ *    item.h
+ *    table.h
+ *    item_subselect.h
+ *    sql_bitmap.h
+ *    unireg.h (going bye bye?)
+ *    sql_udf.h
+ *    item_row.h
+ *    handler.cc
+ *    sql_insert.cc
+ *    opt_range.h
+ *    opt_sum.cc
+ *    item_strfunc.h
+ *    sql_delete.cc
+ *    sql_select.h
+ *
+ *    Since most of these include table.h, I think that would appropriate...
+ */
 typedef uint64_t table_map;          /* Used for table bits in join */
 #if MAX_INDEXES <= 64
 typedef Bitmap<64>  key_map;          /* Used for finding keys */
@@ -72,31 +130,38 @@
 typedef Bitmap<((MAX_INDEXES+7)/8*8)> key_map; /* Used for finding keys */
 #endif
 typedef uint32_t nesting_map;  /* Used for flags of nesting constructs */
+
+#include "unireg.h"
+
 /*
   Used to identify NESTED_JOIN structures within a join (applicable only to
   structures that have not been simplified away and embed more the one
   element)
 */
-typedef uint64_t nested_join_map;
-
-/* query_id */
-typedef uint64_t query_id_t;
-extern query_id_t global_query_id;
-
-/* increment query_id and return it.  */
-inline query_id_t next_query_id() { return global_query_id++; }
-
-/* useful constants */
+typedef uint64_t nested_join_map; /* Needed by sql_select.h and table.h */
+
+/* useful constants */#
 extern const key_map key_map_empty;
 extern key_map key_map_full;          /* Should be threaded as const */
 extern const char *primary_key_name;
 
-#include <libdrizzle/drizzle_com.h>
 #include <vio/violite.h>
-#include "unireg.h"
 
 #include <drizzled/sql_alloc.h>
 
+/**
+ * @TODO Move the following into a drizzled.h header?
+ *
+ * I feel that global variables and functions referencing them directly
+ * and that are used only in the server should be separated out into 
+ * a drizzled.h header file -- JRP
+ */
+typedef uint64_t query_id_t;
+extern query_id_t global_query_id;
+
+/* increment query_id and return it.  */
+inline query_id_t next_query_id() { return global_query_id++; }
+
 #define PREV_BITS(type,A)	((type) (((type) 1 << (A)) -1))
 #define all_bits_set(A,B) ((A) & (B) != (B))
 

=== modified file 'drizzled/scheduler.cc'
--- drizzled/scheduler.cc	2008-07-26 18:02:40 +0000
+++ drizzled/scheduler.cc	2008-08-05 18:43:30 +0000
@@ -17,11 +17,7 @@
   Implementation for the thread scheduler
 */
 
-#ifdef USE_PRAGMA_INTERFACE
-#pragma implementation
-#endif
-
-#include <mysql_priv.h>
+#include <drizzled/mysql_priv.h>
 #include "event.h"
 
 

=== modified file 'drizzled/scheduler.h'
--- drizzled/scheduler.h	2008-07-10 02:09:20 +0000
+++ drizzled/scheduler.h	2008-08-05 18:43:30 +0000
@@ -13,15 +13,16 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
+#ifndef DRIZZLE_SERVER_SCHEDULER_H
+#define DRIZZLE_SERVER_SCHEDULER_H
+
 /*
   Classes for the thread scheduler
 */
 
-#ifdef USE_PRAGMA_INTERFACE
-#pragma interface
-#endif
-
+/* Forward declarations */
 class THD;
+struct event;
 
 /* Functions used when manipulating threads */
 
@@ -50,8 +51,6 @@
 
 #define HAVE_POOL_OF_THREADS 1
 
-struct event;
-
 class thd_scheduler
 {
 public:
@@ -71,3 +70,5 @@
 };
 
 void pool_of_threads_scheduler(scheduler_functions* func);
+
+#endif /* DRIZZLE_SERVER_SCHEDULER_H */

=== modified file 'drizzled/sql_plugin.h'
--- drizzled/sql_plugin.h	2008-07-28 05:56:57 +0000
+++ drizzled/sql_plugin.h	2008-08-05 18:43:30 +0000
@@ -13,8 +13,24 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-#ifndef _sql_plugin_h
-#define _sql_plugin_h
+/** 
+ * @TODO There is plugin.h and also sql_plugin.h.  Ostensibly,  
+ * it seems that the two files exist so that plugin.h can provide an
+ * external API for plugin developers and sql_plugin.h will provide
+ * and internal server API for dealing with those plugins.
+ *
+ * However, there are parts of plugin.h marked "INTERNAL USE ONLY" which
+ * seems to contradict the above...
+ *
+ * Let's figure out a better way of dividing the public and internal API
+ * and name the files more appropriately.
+ *
+ * Also, less #defines, more enums and bitmaps...
+ *
+ */
+
+#ifndef DRIZZLE_SERVER_PLUGIN_H
+#define DRIZZLE_SERVER_PLUGIN_H
 
 class sys_var;
 
@@ -125,4 +141,4 @@
 #define plugin_foreach(A,B,C,D) plugin_foreach_with_mask(A,B,C,PLUGIN_IS_READY,D)
 extern bool plugin_foreach_with_mask(THD *thd, plugin_foreach_func *func,
                                      int type, uint state_mask, void *arg);
-#endif
+#endif /* DRIZZLE_SERVER_PLUGIN_H */

=== modified file 'libdrizzle/drizzle.h'
--- libdrizzle/drizzle.h	2008-08-04 22:09:11 +0000
+++ libdrizzle/drizzle.h	2008-08-05 18:43:30 +0000
@@ -34,7 +34,12 @@
 extern "C" {
 #endif
 
-#ifndef _global_h        /* If not standard header */
+/** 
+ * @TODO cleanup global.h and include only the necessary stuff here... 
+ * 
+ * Also, my_bool and my_socket should go bye-bye...
+ */
+#ifndef DRIZZLE_SERVER_GLOBAL_H   /* If not standard header */
 #include <sys/types.h>
 typedef char my_bool;
 #define STDCALL
@@ -42,7 +47,7 @@
 #ifndef my_socket_defined
 typedef int my_socket;
 #endif /* my_socket_defined */
-#endif /* _global_h */
+#endif /* DRIZZLE_SERVER_GLOBAL_H */
 
 #include <drizzled/version.h>
 #include "drizzle_com.h"

=== modified file 'libdrizzle/drizzle_com.h'
--- libdrizzle/drizzle_com.h	2008-08-04 23:58:04 +0000
+++ libdrizzle/drizzle_com.h	2008-08-05 18:43:30 +0000
@@ -352,7 +352,9 @@
 int32_t	net_real_write(NET *net,const unsigned char *packet, size_t len);
 uint32_t my_net_read(NET *net);
 
-#ifdef _global_h
+
+/** @TODO global.h is actually not needed here... only stdint and protocol.h */
+#ifdef DRIZZLE_SERVER_GLOBAL_H
 void my_net_set_write_timeout(NET *net, uint timeout);
 void my_net_set_read_timeout(NET *net, uint timeout);
 #endif
@@ -437,8 +439,8 @@
 char *get_tty_password(const char *opt_message);
 const char *drizzle_errno_to_sqlstate(unsigned int drizzle_errno);
 
-
-#ifdef _global_h
+/** @TODO Is it necessary to include all of drizzled/global.h here? */
+#ifdef DRIZZLE_SERVER_GLOBAL_H
 ulong STDCALL net_field_length(uchar **packet);
 uint64_t net_field_length_ll(uchar **packet);
 uchar *net_store_length(uchar *pkg, uint64_t length);

=== modified file 'libdrizzle/my_time.h'
--- libdrizzle/my_time.h	2008-07-31 18:57:38 +0000
+++ libdrizzle/my_time.h	2008-08-05 18:43:30 +0000
@@ -26,7 +26,7 @@
 #ifndef _libdrizzle_my_time_h_
 #define _libdrizzle_my_time_h_
 
-#include "drizzled/global.h"
+#include <drizzled/global.h>
 #include "drizzle_time.h"
 
 C_MODE_START

=== modified file 'mystrings/strto.c'
--- mystrings/strto.c	2008-07-13 22:45:08 +0000
+++ mystrings/strto.c	2008-08-05 18:43:30 +0000
@@ -35,7 +35,7 @@
 */
 
 
-#if !defined(_global_h) || !defined(_m_string_h)
+#if !defined(DRIZZLE_SERVER_GLOBAL_H) || !defined(_m_string_h)
 #  error  Calling file must include 'my_global.h' and 'm_string.h'
    /* see 'strtoll.c' and 'strtoull.c' for the reasons */
 #endif

=== modified file 'storage/heap/heap.h'
--- storage/heap/heap.h	2008-08-05 05:01:04 +0000
+++ storage/heap/heap.h	2008-08-05 18:43:30 +0000
@@ -22,9 +22,7 @@
 extern "C" {
 #endif
 
-#ifndef _my_base_h
-#include <my_base.h>
-#endif
+#include <drizzled/base.h>
 #include <mysys/my_pthread.h>
 #include <mysys/thr_lock.h>
 

=== modified file 'storage/heap/heapdef.h'
--- storage/heap/heapdef.h	2008-08-05 05:01:04 +0000
+++ storage/heap/heapdef.h	2008-08-05 18:43:30 +0000
@@ -14,6 +14,8 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
 /* This file is included in all heap-files */
+#ifndef HEAPDEF_H
+#define HEAPDEF_H
 
 #include <drizzled/base.h>		/* This includes global */
 C_MODE_START
@@ -125,3 +127,5 @@
 
 extern pthread_mutex_t THR_LOCK_heap;
 C_MODE_END
+
+#endif /* HEAPDEF_H */

=== modified file 'storage/heap/hp_static.c'
--- storage/heap/hp_static.c	2008-06-25 05:29:13 +0000
+++ storage/heap/hp_static.c	2008-08-05 18:43:30 +0000
@@ -18,8 +18,6 @@
   a shared library
 */
 
-#ifndef _global_h
 #include "heapdef.h"
-#endif
 
 LIST *heap_open_list=0,*heap_share_list=0;

=== modified file 'storage/myisam/mi_static.c'
--- storage/myisam/mi_static.c	2008-07-13 19:39:24 +0000
+++ storage/myisam/mi_static.c	2008-08-05 18:43:30 +0000
@@ -18,9 +18,7 @@
   a shared library
 */
 
-#ifndef _global_h
 #include "myisamdef.h"
-#endif
 
 LIST	*myisam_open_list=0;
 uchar	 myisam_file_magic[]=

=== modified file 'storage/myisam/myisam.h'
--- storage/myisam/myisam.h	2008-07-30 05:33:20 +0000
+++ storage/myisam/myisam.h	2008-08-05 18:43:30 +0000
@@ -21,9 +21,7 @@
 extern "C" {
 #endif
 
-#ifndef _my_base_h
 #include <drizzled/base.h>
-#endif
 #ifndef _m_ctype_h
 #include <m_ctype.h>
 #endif

=== modified file 'storage/myisam/myisamdef.h'
--- storage/myisam/myisamdef.h	2008-07-28 18:30:03 +0000
+++ storage/myisam/myisamdef.h	2008-08-05 18:43:30 +0000
@@ -15,7 +15,7 @@
 
 /* This file is included by all internal myisam files */
 
-#if !defined(MYISAMDEF_H)
+#ifndef MYISAMDEF_H
 #define MYISAMDEF_H
 
 #include "myisam.h"			/* Structs & some defines */
@@ -781,4 +781,4 @@
 #endif
 
 
-#endif
+#endif /* MYISAMDEF_H */

=== modified file 'storage/myisam/myisammrg.h'
--- storage/myisam/myisammrg.h	2008-07-28 02:08:00 +0000
+++ storage/myisam/myisammrg.h	2008-08-05 18:43:30 +0000
@@ -21,9 +21,7 @@
 extern "C" {
 #endif
 
-#ifndef _my_base_h
-#include <my_base.h>
-#endif
+#include <drizzled/base.h>
 #ifndef _myisam_h
 #include <myisam.h>
 #endif

